%define major 1
%define minor 17
%define fix 4

Name: cairo
Version: %{major}.%{minor}.%{fix}
Release: 2
Summary: A vector graphics library
License: LGPL-2.1-only or MPL-1.1
URL: https://www.cairographics.org

Source0: https://cairographics.org/snapshots/cairo-%{version}.tar.xz
Source1: https://cairographics.org/snapshots/cairo-%{version}.tar.xz.sha1
Source2: https://cairographics.org/snapshots/cairo-%{version}.tar.xz.sha1.asc

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
BuildRequires: pkg-config

BuildRequires: expat-devel
BuildRequires: fontconfig-devel
BuildRequires: freetype-devel
BuildRequires: glib2-devel
BuildRequires: libpng-devel
BuildRequires: libX11-devel
BuildRequires: libxcb-devel
BuildRequires: libXext-devel
BuildRequires: libxml2-devel
BuildRequires: libXrender-devel
BuildRequires: lzo-devel
BuildRequires: pixman-devel
BuildRequires: xorg-x11-proto-devel
BuildRequires: xz
BuildRequires: zlib-devel

%description
Cairo is a vector graphics library designed to provide high-quality
display and print output. Currently supported output targets include
the X Window System, OpenGL (via glitz), in-memory image buffers, and
image files (PDF, PostScript, and SVG).  Cairo is designed to produce
identical output on all output media while taking advantage of display
hardware acceleration when available (e.g. through the X Render
Extension or OpenGL).


%package -n libcairo%{major}
Summary: Cairo library

%description -n libcairo%{major}
Contains Cairo library files


%package -n libcairo-gobject%{major}
Summary: Cairo-gobject library
Requires: libcairo%{major} = %{version}-%{release}

%description -n libcairo-gobject%{major}
Cairo bindings for applying with crystal-gobject


%package -n libcairo-script-interpreter%{major}
Summary: Cairo-script-interpreter library
Requires: libcairo%{major} = %{version}-%{release}

%description -n libcairo-script-interpreter%{major}
This package contains the script interpreter for executing and manipulating
cairo execution traces


%package devel
Summary: Cairo developmental libraries and header files
Requires: libcairo%{major} = %{version}-%{release}
Requires: libcairo-gobject%{major} = %{version}-%{release}
Requires: libcairo-script-interpreter%{major} = %{version}-%{release}
Requires: fontconfig-devel
Requires: freetype-devel
Requires: glib2-devel
Requires: libpng-devel
Requires: libxcb-devel
Requires: libXrender-devel
Requires: libX11-devel
Requires: libXext-devel

%description devel
Developmental libraries and header files required for developing or
compiling software which links to the cairo graphics library.


%prep
%setup -q

%build
autoreconf -fiv
%configure \
    LDFLAGS="-Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
    ax_cv_c_float_words_bigendian=yes \
    --with-aix-soname=svr4 \
    --enable-shared \
    --disable-static \
    --enable-svg=no \
    --enable-xlib=yes \
    --enable-xlib-xrender=yes \
    --enable-xcb=yes \
    --enable-png=yes \
    --enable-ps=yes \
    --enable-pdf=yes \
    --enable-pthread=yes \
    --disable-some-floating-point \
    --disable-gtk-doc \
    --enable-gobject
%make_build

%install
%make_install

%files -n libcairo%{major}
%defattr(-, qsys, *none)
%doc AUTHORS BIBLIOGRAPHY BUGS ChangeLog COPYING
%doc COPYING-LGPL-2.1 COPYING-MPL-1.1 NEWS
%doc PORTING_GUIDE README
%{_libdir}/libcairo.so.2

%files -n libcairo-gobject%{major}
%defattr(-, qsys, *none)
%{_libdir}/libcairo-gobject.so.2

%files -n libcairo-script-interpreter%{major}
%defattr(-, qsys, *none)
%{_libdir}/libcairo-script-interpreter.so.2

%files devel
%defattr(-, qsys, *none)
%{_datadir}/gtk-doc/html/cairo/
%{_libdir}/pkgconfig/
%{_includedir}/cairo/
%{_libdir}/libcairo-script-interpreter.so
%{_libdir}/libcairo-gobject.so
%{_libdir}/libcairo.so

%changelog
* Fri Mar 26 2021 Kevin Adler <kadler@us.ibm.com> - 1.17.4
- Add pkg-config dependencies to cairo-devel

* Mon Jan 25 2021 Vasili-Skurydzin <vasili.skurydzin@ibm.com> - 1.16.0
- Minor corrections to build in an IBM environment

* Tue Jul 30 2019 Calvin Buckley <calvin@cmpct.info> - 1.16.0-3
- Switch to X.org

* Thu Mar 28 2019 Calvin Buckley <calvin@cmpct.info> - 1.16.0-2
- Re-enable X11

* Tue Mar 26 2019 Calvin Buckley <calvin@cmpct.info> - 1.16.0-1
- Upgrade to 1.16.0 (some tests failing)
- De-AIX, Rochester conventions
- Disabled X11 and SVG support due to dependency chain problems

* Fri Feb 01 2013 Michael Perzl <michael@perzl.org> - 1.10.2-3
- added missing 64-bit shared members of libcairo-gobject.a and
  libcairo-script-interpreter.a

* Mon Aug 20 2012 Michael Perzl <michael@perzl.org> - 1.10.2-2
- had to switch from IBM XL C/C++ to GCC now as otherwise cairo is miscompiled

* Sun Nov 20 2011 Michael Perzl <michael@perzl.org> - 1.10.2-1
- updated to version 1.10.2

* Sun Nov 20 2011 Michael Perzl <michael@perzl.org> - 1.10.0-1
- updated to version 1.10.0
- added RTL-style shared libraries

* Fri Feb 26 2010 Michael Perzl <michael@perzl.org> - 1.8.10-1
- updated to version 1.8.10

* Wed Jun 24 2009 Michael Perzl <michael@perzl.org> - 1.8.8-1
- updated to version 1.8.8

* Wed Dec 17 2008 Michael Perzl <michael@perzl.org> - 1.8.6-1
- updated to version 1.8.6

* Thu Nov 20 2008 Michael Perzl <michael@perzl.org> - 1.8.4-1
- updated to version 1.8.4

* Sat Nov 01 2008 Michael Perzl <michael@perzl.org> - 1.8.2-1
- updated to version 1.8.2

* Wed Oct 22 2008 Michael Perzl <michael@perzl.org> - 1.8.0-1
- updated to version 1.8.0

* Fri Jul 04 2008 Michael Perzl <michael@perzl.org> - 1.6.4-1
- updated to version 1.6.4

* Sat Apr 05 2008 Michael Perzl <michael@perzl.org> - 1.4.14-1
- first version for AIX V5.1 and higher
